package com.ozs.service.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.ozs.common.annotation.Excel;
import com.ozs.common.core.domain.BaseEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.models.auth.In;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * <p>
 * 报警信息表
 * </p>
 *
 * @author ozs
 * @since 2023-02-22
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@ApiModel("报警信息表")
public class MsgAlarm extends BaseEntity implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键ID
     */
    @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /**
     * 报警唯一标识
     */
    private String alarmId;

    /**
     * 相机编码
     */
    private String cameraCode;

    /**
     * 报警时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date alarmTime;

    /**
     * 报警里程位置
     */
    private Integer alarmMile;

    /**
     * 报警内容
     */
    private String content;

    /**
     * 报警置信度（百分比）
     */
    private Integer alarmConfidence;

    /**
     * 报警行别(1上行2下行)
     */
    private Integer lineDir;

    /**
     * 报警病害类型（目前只有1泥石流，后续可扩展使用）
     */
    private Integer alarmType;

    /**
     * 报警病害属性（可以给出泥石流的框定范围）
     */
    private String alarmAttr;

    /**
     * 报警图片地址
     */
    private String imageUrl;

    /**
     * 解除人
     */
    private String releasedBy;

    /**
     * 解除时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date releasedTime;

    /**
     * 报警是否解除 1已解除2未解除
     */
    private Integer isLock;

    /**
     * 创建人
     */
    private String createBy;

    /**
     * 创建时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /**
     * 修改人
     */
    private String updateBy;

    /**
     * 修改时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    /**
     * 备注
     */
    private String remark;

    /**
     * 线路名称
     */
    @TableField(exist = false)
    private String railwayName;

    /**
     * 监控范围开始里程位置
     */
    @TableField(exist = false)
    private String beginMile;

    /**
     * 监控范围结束里程位置
     */
    @TableField(exist = false)
    private String endMile;

    /**
     * 报警里程位置字符串形式
     */
    @TableField(exist = false)
    private String alarmMiles;

    /**
     * 报警次数
     */
    @TableField(exist = false)
    private Integer alarmCount;

    /**
     * 报警图片地址网络路径
     */
    @TableField(exist = false)
    private List<String> imageUrls;

    /**
     * 解除人真实姓名
     */
    @TableField(exist = false)
    private String releasedByName;
}
